package
Version:
v0.0.10
Opens a new window with list of versions in this module.
Published: Mar 24, 2026
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package backend provides Lua bindings for the boxes and glue backend.
This includes:
- bag: ScaledPoint operations and logging
- node: Node types and list operations
- font: Font shaping
Open registers the backend modules for require() in the Lua state.
Atom wraps the boxesandglue font.Atom type
Font wraps the boxesandglue font.Font type
type NodeDisc struct{ Value *node.Disc }
Node wrapper types
type NodeGlue struct{ Value *node.Glue }
Node wrapper types
type NodeKern struct{ Value *node.Kern }
Node wrapper types
type NodeLang struct{ Value *node.Lang }
Node wrapper types
type NodeRule struct{ Value *node.Rule }
Node wrapper types
Source Files
¶
Click to show internal directories.
Click to hide internal directories.