package
Version:
v0.0.10
Opens a new window with list of versions in this module.
Published: Mar 24, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package textshape provides Lua bindings for the textshape ot package,
exposing low-level text shaping (HarfBuzz-port) to Lua scripts.
Open registers the textshape module for require() in the Lua state.
Buffer wraps an ot.Buffer for Lua.
type Face struct {
Value *ot.Face
}
Face wraps an ot.Face for Lua.
Feature wraps an ot.Feature for Lua.
type Font struct {
Value *ot.Font
}
Font wraps an ot.Font for Lua.
Shaper wraps an ot.Shaper for Lua.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.